#
# spec file for package rss-glx
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rss-glx
Version:        0.9.1
Release:        25.4
Summary:        Really Slick Screensavers Port to GLX
License:        GPL-2.0-only AND GPL-3.0-only
Group:          Amusements/Toys/Screensavers
URL:            http://rss-glx.sourceforge.net/
Source0:         http://prdownloads.sourceforge.net/rss-glx/rss-glx_%{version}.tar.bz2
Source1:         README.SUSE
# PATCH-FIX-OPENSUSE
Patch0:         rss-glx-optflags.patch
# patch should go upstream, but there is TODO: source files include
# magick/MagickCore.h and wand/MagickWand.h. This works for us for
# both ImageMagick-6 and ImageMagick-7 because we package wand/ and
# magick/ symlinks of ImageMagick include dir, but files should
# include MagickCore/MagickCore.h and MagickWand/MagickWand.h for
# ImageMagick-7 instead; the upstream seem to be dead anyway though
Patch1:         rss-glx-ImageMagick7.patch
# PATCH-FIX-UPSTREAM
Patch2:         0001-Fix-build-with-GCC-11.patch
BuildRequires:  Mesa-libGL-devel
BuildRequires:  gcc-c++
# directory ownership
BuildRequires:  libX11-devel
BuildRequires:  libXt-devel
BuildRequires:  libtool
BuildRequires:  openal-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xscreensaver
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(freealut)
BuildRequires:  pkgconfig(glu)

%description
Cool collection of 3D screensavers. Linux port of Really Slick Screensavers -
Web's most visually exciting collection of original, open-source screensavers.


%prep
%setup -q -n %{name}_%{version}
%patch -P 0
%patch -P 1 -p1
%patch -P 2 -p1

%build
autoreconf -fiv
%configure --disable-static \
  --enable-shared \
  --with-pic \
  --with-configdir=%{_sysconfdir}/xscreensaver \
  --program-prefix=""
cp %{SOURCE1} .

%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
#no -devel files here..
rm -rvf %{buildroot}%{_libdir}/*.so

# FIX boo#901450
mkdir -pv %{buildroot}%{_libexecdir}/xscreensaver
pushd %{buildroot}%{_bindir}
for i in `ls` ; do
  mv -vf %{buildroot}%{_bindir}/${i} %{buildroot}%{_libexecdir}/xscreensaver
done
popd
rm -rvf %{buildroot}%{_bindir}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%config %{_sysconfdir}/xscreensaver/*
%{_libdir}/lib*
%{_mandir}/*/*%{ext_man}
%dir %{_libexecdir}/xscreensaver
%{_libexecdir}/xscreensaver/*
%doc README*

%changelog
* Mon Nov 25 2024 Aleksey Kontsevich <akontsevich@gmail.com>
- Moved binaries to libexecdir to avoid conflicts with other packages
* Fri Oct  4 2024 Aleksey Kontsevich <akontsevich@gmail.com>
- Removed "rss-glx" prefix from binaries which prevented them to start and
  to be listed in xscreensaver-settings: no need to distinguish them from
  those screensavers shipped by xscreensaver itself anymore.
- Return back rss-glx_install.pl to patch ~/.xscreensaver and add any missing
  entries.
- Extended package description with install instructions.
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Jun  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add GCC 11 compatibility fix:
  * 0001-Fix-build-with-GCC-11.patch
* Mon Dec  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Remove the unneeded kde4-filesystem build requirement.
* Thu Dec 21 2017 mimi.vx@gmail.com
- Fix license
- Cleanup BuildRequires
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Drop dependency on kdebase4-workspace
* Mon Mar 27 2017 pgajdos@suse.com
- fix build with ImageMagick 7
  + rss-glx-ImageMagick7.patch
* Wed Oct 15 2014 i@marguerite.su
- fix boo#901450
  * soft-link binaries from /usr/bin to %%%%{_libdir}/xscreensaver
- use --program-prefix=rss-glx to distinguish from those
  screensavers shipped by xscreensaver itself.
* Thu Sep 20 2012 coolo@suse.com
- add pkgconfig(glu) as explicit buildrequire
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Nov 25 2011 coolo@suse.com
- change the license to GPL-2.0 as that's what COPYING says and
  I found at least one file without "or later"
* Thu Sep 22 2011 coolo@suse.com
- cleanup spec file
* Fri Sep  2 2011 crrodriguez@opensuse.org
- Fix build with no-add-needed, just by not using static linking
- Fix lack of optflags due to broken configure script
* Thu Jun 24 2010 pascal.bleser@opensuse.org
- update to 0.9.1:
  * added port of Pixel City
  * replaced methods deprecated by ImageMagick
- fix build on < 11.2 by defining _kde4_servicesdir if not already defined
* Thu Dec 24 2009 coolo@novell.com
- initial package
